@@ -76,7 +76,7 @@ except NameError:
 # Dev branch marker is: 'X.Y.dev' or 'X.Y.devN' where N is an integer.
 # 'X.Y.dev0' is the canonical version of 'X.Y.dev'
 #
-__version__ = "2020.1.2"
+__version__ = "2020.1.3"
 
 if __SKOPT_SETUP__:
     import sys
@@ -89,11 +89,13 @@ else:
     from . import acquisition
     from . import benchmarks
     from . import callbacks
+    from . import ext
     from . import learning
     from . import optimizer
 
     from . import space
     from . import sampler
+    from .ext import weighted_validation
     from .optimizer import dummy_minimize
     from .optimizer import forest_minimize
     from .optimizer import gbrt_minimize
@@ -109,6 +111,8 @@ else:
         "acquisition",
         "benchmarks",
         "callbacks",
+        "ext",
+        "weighted_validation",
         "learning",
         "optimizer",
         "plots",
